Implements approximate Bayesian inference for Structural Equation Models (SEM) using a custom adaptation of the Integrated Nested Laplace Approximation (Rue et al., 2009) tools:::Rd_expr_doi("10.1111/j.1467-9868.2008.00700.x") as described in Jamil and Rue (2026a) tools:::Rd_expr_doi("10.48550/arXiv.2603.25690"). Provides a computationally efficient alternative to Markov Chain Monte Carlo (MCMC) for Bayesian estimation, allowing users to fit latent variable models using the 'lavaan' syntax. See also the companion paper on implementation and workflows, Jamil and Rue (2026b) tools:::Rd_expr_doi("10.48550/arXiv.2604.00671").
acfa(): Approximate Confirmatory Factor Analysis.
asem(): Approximate Structural Equation Modelling.
agrowth(): Approximate Latent Growth Curve models.
Supports advanced 'lavaan' syntax features, including:
Equality constraints
Defined parameters (e.g., := operator for indirect effects)
Flexible prior specifications
After fitting a model an INLAvaan object is returned. The following S4 methods are available. See INLAvaan for the class definition.
The package website contains comprehensive examples covering:
Confirmatory Factor Analysis (CFA)
Structural Equation Models (SEM)
Latent Growth Curve Models
Multigroup and Invariance Testing
Mediation Analysis
Maintainer: Haziq Jamil haziq.jamil@gmail.com (ORCID) [copyright holder]
Other contributors:
Håvard Rue (ORCID) (Statistical and computational methodology) [contributor]
Alvin Bong (Initial site build) [contributor]
Useful links: