Learn R Programming

INLAvaan (version 0.2.3)

fitMeasures,INLAvaan-method: Fit Measures for a Latent Variable Model estimated using INLA

Description

Fit Measures for a Latent Variable Model estimated using INLA

Usage

# S4 method for INLAvaan
fitMeasures(object, fit.measures = "all", baseline.model = NULL)

# S4 method for INLAvaan fitmeasures(object, fit.measures = "all", baseline.model = NULL)

Value

A named numeric vector of fit measures.

Arguments

object

An object of class INLAvaan.

fit.measures

If "all", all fit measures available will be returned. If only a single or a few fit measures are specified by name, only those are computed and returned.

baseline.model

Not currently used, added for compatability with {lavaan}.