is_same_function: Helper function to check if two functions are the same

View source: R/utils.R

is_same_functionR Documentation

Helper function to check if two functions are the same

Description

Helper function to check if two functions are the same

Usage

is_same_function(f, g)

Arguments

f, g

Functions to compare.

Value

Logical.

Examples

f1 <- function(x) { x^2 + 1 }
f2 <- function(x) { x^2 + 1 }
is_same_function(f1, f2)  # TRUE

INLAvaan documentation built on Oct. 2, 2026, 1:07 a.m.