| INLAvaan-class | R Documentation |
This is a class that extends the lavaan class. Several S4 methods are available.
## S4 method for signature 'INLAvaan'
coef(object, ...)
## S4 method for signature 'INLAvaan'
nobs(object, ...)
## S4 method for signature 'INLAvaan'
show(object)
## S4 method for signature 'INLAvaan'
summary(
object,
header = TRUE,
fit.measures = TRUE,
estimates = TRUE,
ci = TRUE,
standardized = FALSE,
standardised = standardized,
rsquare = FALSE,
postmedian = FALSE,
postmode = FALSE,
nmad = TRUE,
kld = FALSE,
vb_shift = FALSE,
priors = TRUE,
nd = 3L,
...
)
object |
An object of class |
... |
Additional arguments passed to methods. |
header |
Logical; if TRUE, print model fit information header. |
fit.measures |
Logical; if TRUE, print fit measures (DIC and pD;
PPP is printed by the header regardless). Both require the fit to
have computed them, see the |
estimates |
Logical; if TRUE, print parameter estimates table. |
ci |
Logical; if TRUE (default), include 95% credible intervals (2.5% and 97.5% posterior quantiles) in the estimates table. |
standardized |
Logical; if TRUE, include standardized estimates. |
standardised |
Alias of |
rsquare |
Logical; if TRUE, include R-square values for the observed dependent variables, computed at the posterior mean point estimates. |
postmedian |
Logical; if TRUE, include posterior median in estimates. |
postmode |
Logical; if TRUE, include posterior mode in estimates. |
nmad |
Logical; if TRUE (default), include the NMAD column for skew-normal marginal fit quality. |
kld |
Logical; if FALSE (default), omit the per-parameter KLD column. Set to TRUE to show it. |
vb_shift |
Logical; if FALSE (default), omit the VB shift column (shift in units of posterior SD). Set to TRUE to show it. |
priors |
Logical; if TRUE, include prior information in estimates. |
nd |
Integer; number of decimal places to print for numeric values. |
externalA list containing an inlavaan_internal object.
lavaan, inlavaan(), acfa(), asem(), agrowth()
HS.model <- "
visual =~ x1 + x2 + x3
textual =~ x4 + x5 + x6
speed =~ x7 + x8 + x9
"
utils::data("HolzingerSwineford1939", package = "lavaan")
fit <- acfa(HS.model, HolzingerSwineford1939, std.lv = TRUE, nsamp = 100,
test = "none", verbose = FALSE)
# Print basic info
fit
# Detailed summary
summary(fit)
# Extract coefficients
coef(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.