Learn R Programming

INLAvaan (version 0.2.3)

INLAvaan-class: Class For Representing a (Fitted) Latent Variable Model

Description

This is a class that extends the lavaan::lavaan class. Several S4 methods are available.

Usage

# S4 method for INLAvaan,ANY
plot(x, y, ...)

# S4 method for INLAvaan predict(object, nsamp = 1000, ...)

# S4 method for INLAvaan show(object)

# S4 method for INLAvaan coef(object)

# S4 method for INLAvaan summary( object, header = TRUE, fit.measures = TRUE, estimates = TRUE, standardized = FALSE, rsquare = FALSE, postmedian = FALSE, postmode = FALSE, priors = TRUE, nd = 3L, ... )

# S4 method for INLAvaan vcov(object)

Arguments

x

An object of class INLAvaan.

y

Not used.

...

Not used.

object

An object of class INLAvaan.

nsamp

The number of samples to draw for all sampling-based approaches (including posterior sampling for model fit indices).

header

Logical; if TRUE, print model fit information header.

fit.measures

Logical; if TRUE, print fit measures (DIC and PPP).

estimates

Logical; if TRUE, print parameter estimates table.

standardized

Logical; if TRUE, include standardized estimates.

rsquare

Logical; if TRUE, include R-square values.

postmedian

Logical; if TRUE, include posterior median in estimates.

postmode

Logical; if TRUE, include posterior mode in estimates.

priors

Logical; if TRUE, include prior information in estimates.

nd

Integer; number of decimal places to print for numeric values.

Slots

external

A list containing an inlavaan_internal object.

See Also

lavaan::lavaan