This is a class that extends the lavaan::lavaan class. Several S4 methods are available.
# S4 method for INLAvaan,ANY
plot(x, y, ...)# S4 method for INLAvaan
predict(object, nsamp = 1000, ...)
# S4 method for INLAvaan
show(object)
# S4 method for INLAvaan
coef(object)
# S4 method for INLAvaan
summary(
object,
header = TRUE,
fit.measures = TRUE,
estimates = TRUE,
standardized = FALSE,
rsquare = FALSE,
postmedian = FALSE,
postmode = FALSE,
priors = TRUE,
nd = 3L,
...
)
# S4 method for INLAvaan
vcov(object)
An object of class INLAvaan.
Not used.
Not used.
An object of class INLAvaan.
The number of samples to draw for all sampling-based approaches (including posterior sampling for model fit indices).
Logical; if TRUE, print model fit information header.
Logical; if TRUE, print fit measures (DIC and PPP).
Logical; if TRUE, print parameter estimates table.
Logical; if TRUE, include standardized estimates.
Logical; if TRUE, include R-square values.
Logical; if TRUE, include posterior median in estimates.
Logical; if TRUE, include posterior mode in estimates.
Logical; if TRUE, include prior information in estimates.
Integer; number of decimal places to print for numeric values.
externalA list containing an inlavaan_internal object.
lavaan::lavaan