Fit Measures for a Latent Variable Model estimated using INLA
# S4 method for INLAvaan
fitMeasures(object, fit.measures = "all", baseline.model = NULL)# S4 method for INLAvaan
fitmeasures(object, fit.measures = "all", baseline.model = NULL)
A named numeric vector of fit measures.
An object of class INLAvaan.
If "all", all fit measures available will be returned. If
only a single or a few fit measures are specified by name, only those are
computed and returned.
Not currently used, added for compatability with {lavaan}.