| fit_skew_normal_samp | R Documentation |
Fit a skew normal distribution to a sample
fit_skew_normal_samp(x)
x |
A numeric vector of sample data. |
Uses maximum likelihood estimation to fit a skew normal distribution
to the provided numeric vector x.
A list with fitted parameters:
xi: location parameter
omega: scale parameter
alpha: shape parameter
logC: log-normalization constant
k: temperature parameter
rsq: R-squared of the fit
Note that logC and k are not used when fitting from a sample.
x <- rnorm(100, mean = 5, sd = 1)
unlist(fit_skew_normal_samp(x))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.