powered by
Fit a skew normal distribution to a sample
fit_skew_normal_samp(x)
A list with fitted parameters:
xi: location parameter
xi
omega: scale parameter
omega
alpha: shape parameter
alpha
logC: log-normalization constant
logC
k: temperature parameter
k
rsq: R-squared of the fit
rsq
Note that logC and k are not used when fitting from a sample.
A numeric vector of sample data.
Uses maximum likelihood estimation to fit a skew normal distribution to the provided numeric vector x.
x
x <- rnorm(100, mean = 5, sd = 1) unlist(fit_skew_normal_samp(x))
Run the code above in your browser using DataLab