| timing | R Documentation |
Extract wall-clock timings for individual computation stages of a fitted
INLAvaan model.
timing(object, ...)
## S4 method for signature 'INLAvaan'
timing(object, what = "total", ...)
object |
An object of class INLAvaan. |
... |
Currently unused. |
what |
Character vector of timing segment names to return, or
|
A named numeric vector (class c("timing.INLAvaan",
"numeric")) of elapsed times in seconds. Printing formats short
durations as seconds, longer ones as minutes or hours.
diagnostics(), summary()
HS.model <- "
visual =~ x1 + x2 + x3
textual =~ x4 + x5 + x6
speed =~ x7 + x8 + x9
"
utils::data("HolzingerSwineford1939", package = "lavaan")
fit <- acfa(HS.model, HolzingerSwineford1939, std.lv = TRUE, nsamp = 100,
test = "none", verbose = FALSE)
# Total elapsed time
timing(fit)
# All stages
timing(fit, what = "all")
# Specific stages
timing(fit, what = c("optim", "marginals"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.